'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = routes;

var _koaRouter = _interopRequireDefault(require("koa-router"));

var _koaCsrf = _interopRequireDefault(require("koa-csrf"));

var _oauth = _interopRequireDefault(require("./oauth"));

var user = _interopRequireWildcard(require("./controllers/user"));

var admin = _interopRequireWildcard(require("./controllers/admin"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function routes(app, config) {
  const R = config.routes;
  const oauth = (0, _oauth.default)(config);
  const authRouter = new _koaRouter.default(); // API: get user info

  authRouter.get(R.user, oauth.authenticate, user.getInfo); // OAuth

  authRouter.get(R.authorize, user.checkLogin, oauth.authorize);
  authRouter.post(R.access_token, oauth.accessToken);
  const router = new _koaRouter.default();
  router.get(R.home, user.checkLogin, user.home); // Login & Logout

  router.get(R.login, user.login);
  router.get(R.logout, user.logout);
  router.post(R.send_token, user.sendToken);
  router.post(R.session, user.session); // Reset password

  router.get(R.password_reset, user.passwordResetPage);
  router.post(R.password_reset, user.passwordReset); // Change password

  router.get(R.password_change, user.passwordChangePage);
  router.post(R.password_change, user.passwordChange); // Admin

  router.get(R.admin.users, admin.checkLogin, admin.userList);
  router.post(R.admin.search_user, admin.checkLogin, admin.searchUser);
  router.get(R.admin.clients, admin.checkLogin, admin.clientList);
  router.post(R.admin.send_totp, admin.checkLogin, admin.sendTotp);
  router.post(R.admin.add_client, admin.checkLogin, admin.addClient);
  router.post(R.admin.generate_secret, admin.checkLogin, admin.generateSecret);
  router.get(R.admin.roles, admin.checkLogin, admin.roleList);
  router.post(R.admin.add_role, admin.checkLogin, admin.addRole);
  router.post(R.admin.delete_role, admin.checkLogin, admin.deleteRole);
  app.use(authRouter.routes());
  app.use(authRouter.allowedMethods());
  app.use(new _koaCsrf.default());
  app.use(async (ctx, next) => {
    ctx.state._csrf = ctx.csrf;
    ctx.cookies.set('XSRF-TOKEN', ctx.csrf, {
      httpOnly: false
    });
    await next();
  });
  app.use(router.routes());
  app.use(router.allowedMethods());
}

module.exports = exports.default;